ScreenGoModel class

Constructors

ScreenGoModel({required double screenHeight, required double screenWidth, required Orientation orientation, required double parentHeight, required double parentWidth, required DeviceScreenType screenType, required DeviceType deviceType})

Properties

deviceType → DeviceType
final
hashCode → int
The hash code for this object.
no setterinherited
orientation → Orientation
final
parentHeight → double
final
parentWidth → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenHeight → double
final
screenType → DeviceScreenType
final
screenWidth → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited